API
===

.. _api_dataset_ref:

:mod:`gradec.dcode`: Decoder algorithms
--------------------------------------------------

.. automodule:: gradec.decode
   :no-members:
   :no-inherited-members:

.. currentmodule:: gradec

.. autosummary::
   :toctree: generated/
   :template: class.rst

   decode.TermDecoder
   decode.LDADecoder
   decode.GCLDADecoder


.. _api_meta_ref:

:mod:`gradec.model`: Meta-analytic models
--------------------------------------------------

.. automodule:: gradec.model
   :no-members:
   :no-inherited-members:

.. currentmodule:: gradec

.. autosummary::
   :toctree: generated/
   :template: module.rst

   model.LDAModel
   model.annotate_lda

.. _api_results_ref:

:mod:`gradec.segmentation`: Segmentation algorithms
------------------------------------------------------

.. automodule:: gradec.segmentation
   :no-members:
   :no-inherited-members:

.. currentmodule:: gradec

.. autosummary::
   :toctree: generated/
   :template: class.rst

   segmentation.PCTSegmentation
   segmentation.KMeansSegmentation

.. _api_correct_ref:

.. _api_utils_ref:

:mod:`gradec.utils`: Utility functions and submodules
-----------------------------------------------------

.. automodule:: gradec.utils
   :no-members:
   :no-inherited-members:

.. currentmodule:: gradec

.. autosummary::
   :toctree: generated/
   :template: function.rst

   utils.get_data_dir
